summaryrefslogtreecommitdiffstats
path: root/cmake/modules/FindPolkitQt-1.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/modules/FindPolkitQt-1.cmake')
-rw-r--r--cmake/modules/FindPolkitQt-1.cmake20
1 files changed, 10 insertions, 10 deletions
diff --git a/cmake/modules/FindPolkitQt-1.cmake b/cmake/modules/FindPolkitQt-1.cmake
index 30d27de15..f28c494e4 100644
--- a/cmake/modules/FindPolkitQt-1.cmake
+++ b/cmake/modules/FindPolkitQt-1.cmake
@@ -1,4 +1,4 @@
# - Try to find PolkitQt-1
# Once done this will define
#
# POLKITQT-1_FOUND - system has Polkit-qt
@@ -9,8 +9,8 @@
# POLKITQT-1_AGENT_LIBRARY - Link this to use the agent wrapper in polkit-qt
# POLKITQT-1_DEFINITIONS - Compiler switches required for using Polkit-qt
#
# The minimum required version of PolkitQt-1 can be specified using the
# standard syntax, e.g. find_package(PolkitQt-1 1.0)
# Copyright (c) 2010, Dario Freddi, <drf@kde.org>
#
@@ -18,16 +18,16 @@
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
# Support POLKITQT-1_MIN_VERSION for compatibility:
-if ( NOT PolkitQt-1_FIND_VERSION AND POLKITQT-1_MIN_VERSION )
- set ( PolkitQt-1_FIND_VERSION ${POLKITQT-1_MIN_VERSION} )
-endif ( NOT PolkitQt-1_FIND_VERSION AND POLKITQT-1_MIN_VERSION )
+if ( NOT PolkitTQt-1_FIND_VERSION AND POLKITQT-1_MIN_VERSION )
+ set ( PolkitTQt-1_FIND_VERSION ${POLKITQT-1_MIN_VERSION} )
+endif ( NOT PolkitTQt-1_FIND_VERSION AND POLKITQT-1_MIN_VERSION )
-set( _PolkitQt-1_FIND_QUIETLY ${PolkitQt-1_FIND_QUIETLY} )
-find_package( PolkitQt-1 ${PolkitQt-1_FIND_VERSION} QUIET NO_MODULE PATHS ${LIB_INSTALL_DIR}/PolkitQt-1/cmake )
-set( PolkitQt-1_FIND_QUIETLY ${_PolkitQt-1_FIND_QUIETLY} )
+set( _PolkitTQt-1_FIND_QUIETLY ${PolkitTQt-1_FIND_QUIETLY} )
+find_package( PolkitTQt-1 ${PolkitTQt-1_FIND_VERSION} TQUIET NO_MODULE PATHS ${LIB_INSTALL_DIR}/PolkitTQt-1/cmake )
+set( PolkitTQt-1_FIND_QUIETLY ${_PolkitTQt-1_FIND_QUIETLY} )
include( FindPackageHandleStandardArgs )
-find_package_handle_standard_args( PolkitQt-1 DEFAULT_MSG PolkitQt-1_CONFIG )
+find_package_handle_standard_args( PolkitTQt-1 DEFAULT_MSG PolkitTQt-1_CONFIG )
if (POLKITQT-1_FOUND)
if (NOT POLKITQT-1_INSTALL_DIR STREQUAL CMAKE_INSTALL_PREFIX)
@@ -1,4 +1,4 @@
-# - Try to find PolkitQt-1
+# - Try to find PolkitTQt-1
# Once done this will define
#
@@ -9,8 +9,8 @@
# POLKITQT-1_DEFINITIONS - Compiler switches required for using Polkit-qt
#
-# The minimum required version of PolkitQt-1 can be specified using the
-# standard syntax, e.g. find_package(PolkitQt-1 1.0)
+# The minimum required version of PolkitTQt-1 can be specified using the
+# standard syntax, e.g. find_package(PolkitTQt-1 1.0)
# Copyright (c) 2010, Dario Freddi, <drf@kde.org>
#